Coverage report

Module | statements | missing | excluded | branches | partial | coverage
--- | --- | --- | --- | --- | --- | ---
.tox/cov/lib/python3.11/site-packages/confattr/__init__.py | 8 | 0 | 2 | 0 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/config.py | 261 | 0 | 34 | 123 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/configfile.py | 1375 | 0 | 47 | 645 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/formatters.py | 337 | 0 | 31 | 170 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/quickstart.py | 92 | 0 | 0 | 10 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/state.py | 2 | 0 | 0 | 0 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/subprocess_pipe.py | 32 | 0 | 0 | 6 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/types.py | 155 | 0 | 12 | 68 | 0 | 100%
.tox/cov/lib/python3.11/site-packages/confattr/utils.py | 124 | 0 | 11 | 36 | 0 | 100%
Total | 2386 | 0 | 137 | 1058 | 0 | 100%

No items found using the specified filter.